#
# spec file for package vapoursynth
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           vapoursynth
Version:        65
Release:        2.2
Summary:        A video processing framework
License:        LGPL-2.1-only
Group:          Productivity/Multimedia/Video/Editors and Convertors
URL:            http://www.vapoursynth.com/
Source0:        https://github.com/vapoursynth/vapoursynth/archive/R%{version}.tar.gz#/%{name}-R%{version}.tar.gz
# PATCH-FIX-OPENSUSE vapoursynth-version.patch -- makes sure that we have
# some sort of version for othervise unversioned .so files
Patch0:         vapoursynth-version.patch
# Patch to revert for Leap 15.x builds
Patch1:         ac62a4d2a54bacccd09b97453bffe759c01f18ef.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  python3-Cython
BuildRequires:  pkgconfig(Magick++) >= 7.0
BuildRequires:  pkgconfig(libarchive)
BuildRequires:  pkgconfig(libass)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(tesseract)
BuildRequires:  pkgconfig(zimg) >= 2.9.2
Obsoletes:      plugin-eedi3
Obsoletes:      plugin-imwri
Obsoletes:      plugin-miscfilters
Obsoletes:      plugin-morpho
Obsoletes:      plugin-ocr
Obsoletes:      plugin-removegrain
Obsoletes:      plugin-subtext
Obsoletes:      plugin-vinverse
Obsoletes:      plugin-vivtc
%if 0%{?suse_version} <= 1500
BuildRequires:  gcc12
BuildRequires:  gcc12-PIE
BuildRequires:  gcc12-c++
%else
BuildRequires:  gcc-c++
%endif

%description
VapourSynth is a library for video manipulation. It has a core
library written in C++ and a Python module to allow video scripts to
be created.

%package -n libvapoursynth-%{version}
Summary:        A video processing framework
Group:          System/Libraries
Obsoletes:      libvapoursynth

%description -n libvapoursynth-%{version}
VapourSynth's core library with a C++ API.

%package -n libvapoursynth-script0
Summary:        Library for interfacing Python with VapourSynth
Group:          System/Libraries
Requires:       python3-%{name}

%description -n libvapoursynth-script0
VSScript (or libvapoursynth-script) is a library for interfacing Python
with VapourSynth.

%package -n python3-%{name}
Summary:        Python interface for VapourSynth
Group:          Development/Languages/Python

%description -n python3-%{name}
Python interface for VapourSynth/VSSCript.

%package devel
Summary:        Development files for VapourSynth
Group:          Development/Libraries/C and C++
Requires:       libvapoursynth-%{version} = %{version}
Requires:       libvapoursynth-script0 = %{version}

%description devel
Header files and pkg-config headers for VapourSynth.

%package tools
Summary:        Extra tools for VapourSynth
Group:          Productivity/Multimedia/Video/Editors and Convertors

%description tools
This package contains the vspipe tool for interfacing with
VapourSynth.

%prep
%setup -q -n %{name}-R%{version}
%patch0 -p1
%if 0%{?suse_version} <= 1500
%patch1 -p1 -R
%endif

%build
%if 0%{?suse_version} <= 1500
export CC="gcc-12"
export CXX="g++-12"
%endif

autoreconf -fiv
%if 0%{?suse_version} <= 1500
# Woraround for old autoconf
sed -z -i "s|PACKAGE_URL='http://www.vapoursynth.com/\n'|PACKAGE_URL='http://www.vapoursynth.com/'|" configure
%endif
%configure \
  --disable-static
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post   -n libvapoursynth-%{version} -p /sbin/ldconfig
%postun -n libvapoursynth-%{version} -p /sbin/ldconfig
%post   -n libvapoursynth-script0 -p /sbin/ldconfig
%postun -n libvapoursynth-script0 -p /sbin/ldconfig

%files -n libvapoursynth-%{version}
%license COPYING.LESSER
%doc ChangeLog
%{_libdir}/libvapoursynth-%{version}.so

%files -n libvapoursynth-script0
%{_libdir}/libvapoursynth-script.so.0*

%files -n python3-%{name}
%{python3_sitearch}/*.so

%files devel
%doc doc/
%{_includedir}/vapoursynth/
%{_libdir}/libvapoursynth.so
%{_libdir}/libvapoursynth-script.so
%{_libdir}/pkgconfig/*

%files tools
%{_bindir}/vspipe

%changelog
* Mon Dec  4 2023 Steve Kowalik <steven.kowalik@suse.com>
- Upstream supports Cython 0.29 and 3, stop special casing it.
* Mon Oct 30 2023 Michael Vetter <mvetter@suse.com>
- Update to 65:
  * fixed inspection api sometimes causing memory corruption when
    used from python
  * frame properties in python are now return as str type instead
    of bytes when hinted as utf8 printable
  * fixed how unprintable data is returned from plugin functions
    in python, previously it would leak a ctypes pointer
  * with no length instead of returning a bytes object
  * fixed a bug in the avx2 maskedmerge float premultiplied code
    path that would switch the two input clips
  * reverted the from_chars code a bit more to make no locale affect
    float parsing
  * fixed the sar adjustment for real this time
* Thu Oct 12 2023 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Fix build on Leap 15.x
- Add patch to revert for Leap 15.x only:
  * ac62a4d2a54bacccd09b97453bffe759c01f18ef.patch
* Wed Sep 27 2023 Michael Vetter <mvetter@suse.com>
- Update to 64:
  * fixed compilation on osx where the default standard library
    doesn't have a full implementation of std::from_chars
  * fixed SAR adjustment in resizer when source cropping is used
  * added -- as an alternate to . to indicate no output in vspipe
    since shells have a tendency to expand .
  * added json output of video frame properties to vspipe
  * fixed clearMap function, previously it would forget to properly
    clear the error state in maps which could cause
  * crashes in frameeval and other filters
  * 32 bit binaries are no longer provided for windows
  * updated zimg to fix issues on zen4 cpus
  * added support for cython 3.x
* Sat Sep 23 2023 munix9@googlemail.com
- Fix build on Factory/TW: requires python3-Cython0
- Fix build on Leap 15.4/15.5: requires gcc/gcc-c++ >= 11
* Fri Jun 23 2023 Michael Vetter <mvetter@suse.com>
- Update to 63:
  * Updat all api documentation for api4
  * Switch to C++17 for the entire project
  * Add a warning every time the deprecated cache filter is instantiated and ignored
  * Fix a regression with alpha nodes in vspipe introduced in r62
* Fri Mar 31 2023 Michael Vetter <mvetter@suse.com>
- Update to 62:
  * updated the supported python versions to 3.11 and 3.8
  * now up to 500 log messages are cached when no log handler is attached
  * improvements to repr, audio channel handling and other python fixes
  * added a class Local for environment-local values
- Refresh vapoursynth-version.patch
- Remove plugins. All plugins now available at https://vsdb.top/
* Mon Aug 16 2021 Michael Vetter <mvetter@suse.com>
- Update to 54:
  * Floating point mask clips are now a consistent thing
- Remove vapoursynth-include.patch: upstreamed
* Tue Jul 13 2021 Michael Vetter <mvetter@suse.com>
- Fix build with gcc11:
  Add vapoursynth-include.patch
  See:
  * https://github.com/vapoursynth/vapoursynth/issues/686
  * https://github.com/vapoursynth/vapoursynth/issues/688
  * and commits b5ed913f, a4c4eba7
* Thu Apr 29 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 53:
  * Bugfix release
* Mon Aug 24 2020 Michael Vetter <mvetter@suse.com>
- Update to 52:
  * updated visual studio 2019 runtime version
  * updated zimg
  * updated vsrepo with support for python wheel packages
  * vsgenstubs is now included with vsrepo
  * fixed maximum for 16 bit input with diagonal filters and optimizations
  * fixed deadlock in fmserial filters introduced in r51
  * fixed more averageframes bugs
* Tue Aug 11 2020 Michael Vetter <mvetter@suse.com>
- Update to 51:
  * updated visual studio 2019 runtime version
  * fixed a cache shrinking issue
  * fixed a crash when removing a message handler without a free function
  * fixed an extremely rare threading issue only affecting
    fmparallelrequests filters and arframeready events
  * fixed compilation when avs+ master is used
  * fixed lut and lut2 triggering a fatal error when invalid
    planes were specified
  * fixed property append operations on non-empty keys not properly
    copying the underlying data
  * fixed wave64 headers generated by avfs
  * fixed crash in averageframes with odd number of clips
  * scale averageframes for integer chroma by distance from grey
  * several fixes and improvements regarding handling of the active
    script environment in python
  * plugin loading now has better error messages
  * using get_core() in python now generates a deprecation warning
    since it's been deprecated for years
* Thu May 14 2020 Michael Vetter <mvetter@suse.com>
- Update to 50:
  * Updated zimg to latest v2.9 so grayscale colorspace are supported
  * Fixed several minor issues related to path handling in vsrepo
  * Added version and api_version to python module to make
    detecting version mismatches easier
  * Improved rounding in averageframes
  * Fixed averageframes not properly rejecting more than 31
    weights or nodes
  * Fixed crash in textfilter line wrapping introduced in r49
  * Fixed regression introduced in r48 where expr, sobel and
    prewitt wouldn't clamp 9-15 bit output to valid range
  * Fixed crash due to null pointer dereference when instantiation
    many vapoursynth classes directly in python
* Fri Apr 24 2020 Michael Vetter <mvetter@suse.com>
- Update to version 49:
  * Updated to python 3.8 on windows
  * Updated visual studio 2019 runtime version
  * Updated zimg and added support for spline64 resize method
  * Fixed transfer characteristics not being applied to gray
    format clips
  * Fixed vdecimate bugs when compiled on systems where char is
    unsigned by default
  * Fixed a regression introduced in r48 in that could sometimes
    cause corrupt output from expr on cpus without sse4.1
  * Fixed a savestring bug in avscompat
  * Interleave, selectevery and separate fields now have a
    modify_duration argument to determine if they modify frame
    durations and fps
  * Addborders and crop now update the _fieldbased attribute
    properly when an odd number of lines are cut from the top
  * Fixed add to path not working for single user installs
  * Fixed compilation on non-x86 systems
  * Fixed an infinite loop in the expr filter optimizer that
    was introduced in r48
- Remove python38-compile.patch: contained in upstream
- Rebase vapoursynth-version.patch
* Tue Mar 10 2020 Steve Kowalik <steven.kowalik@suse.com>
- Add patch python38-compile.patch to build against Python 3.8, from
  upstream.
* Thu Jan  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Add the missing libarchive dependency.
* Fri Dec 20 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 48:
  * it's now possible to select which optimized code path is used
    for internal filters (sekrit-twc)
  * avx2 optimization in many filters, previously the internal
    ones were mostly sse2 (sekrit-twc)
  * expr filter can now better optimize expressions (sekrit-twc)
  * the 7zip executable is now bundled with vsrepo
  * the portable version now includes the documentation as well
  * the portable version now includes all the plugins bundled with
    the normal installer again
  * fixed deadlock when setMessageHandler is called a second time
  * added an option to add vspipe, avfs and vsrepo to path in the
    installer
  * added registry entries for the path to vspipe and vsrepo
  * imwri is now included in the installer
  * the overwrite argument in imwri now also disables the
    requirement for output filesnames to contain a number
  * fixed corrupt output from imwri when requesting alpha output
    but the read image doesn't have an alpha channel
- Changes for 47.2:
  * fixed broken merge intrinsics
- Changes for 47.1:
  * fixed linux and non-x86 builds
* Mon Aug  5 2019 mvetter@suse.com
- Update to 47:
  * fixed a crash in vdecimate when both dryrun and clip2 is set (no1d)
  * updated zimg to 2.9.2 to fix a crash that would happen on certain invalid input combinations
  * removed dependency on nasm
  * improved message handler api and core info api
  * various installer improvements including a warning if the vs2019 runtimes aren't installed
- Update vapoursynth-version.patch
* Mon Jul  1 2019 mvetter@suse.com
- Update to version 46:
  * added a fallback to how the appdata path is retrieved which
    works even if %%USERPROFILE%% isn't set
  * the default number of threads used is now based on the process
    affinity on windows, linux and bsd
  * added an option to vspipe to make it not modify the current
    working directory
  * added a better equality check for the Format class in python
  * fixed doubleweave sometimes using the opposite field order (dubhater)
  * fixed broken output when stride wasn't equal to width in the
    python output function (stuxcrystal)
  * relaxed mask clip requirements in maskedmerge (dubhater)
  * fixed overflow with int16 in maskedmerge (dubhater)
  * fixed swapped fields in doubleweave (dubhater)
  * fixed selectevery breaking and leaking when there are no frames to return
* Mon Jan  7 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 45 (boo#1120873):
  * avfs now uses utf8 filename support when available in avs+
  * avfs now prints the used mount point
  * removed accept_lowecase setting from the python bindings
  * fixed frame duration calculation in clipinfo (dubhater)
  * fixed bug that prevented adding vertical margins in subtext
    (dubhater)
  * documentation updates
- Changes for version 44:
  * fixed crop with compatbgr32 format where top and bottom crop
    would be switched
  * fixed crash in scdetect with one frame clips, now it simply
    returns an error since the operation is pointless
  * fixed potential multithreading issues in vsscript (stuxcrystal)
  * the resizer will now properly apply a shift even if no actual
    resizing/format conversion is being done
  * added experimental large page support and changed cache logic
    (sekrit-twc)
  * minor documentation updates
- Drop no longer needed patch:
  * vapoursynth-upstream-fix-for-aarch64.patch
* Thu Apr 26 2018 guillaume.gardet@opensuse.org
- Add patch to fix aarch64 build:
  * vapoursynth-upstream-fix-for-aarch64.patch
* Fri Feb 16 2018 olaf@aepfle.de
- Obsolete libvapoursynth to cleanup old packages during upgrade
* Fri Feb  9 2018 mpluskal@suse.com
- Update to version 43:
  * Mostly bugfixes and internal changes (see provided ChangeLog
    for details)
* Sun Dec  3 2017 mpluskal@suse.com
- Create subpackag for python bindings
- Enable libass, ffmpeg, ImageMagick and Tesseract OCR support
* Thu Nov 30 2017 jengelh@inai.de
- vapoursynth-devel needs to pull in libvapoursynth-script0
* Mon Nov 27 2017 mpluskal@suse.com
- Rename previously added patch to match our patching guidelines:
  * vapoursynth-version.patch
* Mon Nov 27 2017 jengelh@inai.de
- Correct package version (it is 40 not R40, as per configure.ac).
- Resolve project ambiguity in %%description.
- Add SLPP versioning to libvapoursynth.
- Add missing Group: tags to subpackages.
- Move bigger doc directory to -devel.
* Mon Nov 20 2017 mpluskal@suse.com
- Update to version R40
- Clean up spec file a bit
* Sat Nov  5 2016 antispace@codesector.co
- Updated to R35
- Added disclaimer comment block
- Renamed plugin package names to include 'plugin-'
* Sat Oct 22 2016 antispace@codesector.co
- Cleaned up package descriptions and Summary tags
* Sat Oct 22 2016 antispace@codesector.co
- Renamed main package to libvapoursynth
* Sat Oct 22 2016 antispace@codesector.co
- Packaged R34
- Split plugins into their own separate packages
